@@ -6,6 +6,8 @@ import socket
 
 from adbpy.socket import Socket
 
+DEFAULT_ADB_PORT = 5037
+
 class AdbProcess(object):
 
     def __init__(self, path, address):
@@ -14,7 +16,12 @@ class AdbProcess(object):
 
     def start(self):
         null = open(os.devnull, 'w')
-        cmd = '"{0}" -P {1} start-server'.format(self.path, self.address[1])
+
+        port_str = ""
+        if self.address[1] != DEFAULT_ADB_PORT:
+            port_str = "-P " + str(self.address[1])
+
+        cmd = '"{0}" {1} start-server'.format(self.path, port_str)
         return subprocess.call(cmd, shell=True, stdout=null) == 0
 
     def running(self):
